# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`wildfly`](#wildfly): Main class, includes all other classes.
* [`wildfly::external_facts`](#wildfly--external_facts): Set external wildflty facts
* [`wildfly::install`](#wildfly--install): Downloads and installs Wildfly from a remote source or a system package.
* [`wildfly::prepare`](#wildfly--prepare): Manages Wildfly requirements (user, group, dirs and packages)
* [`wildfly::secure_mgmt_api`](#wildfly--secure_mgmt_api): Manages secure management api
* [`wildfly::service`](#wildfly--service): Manages Wildfly service.
* [`wildfly::service::systemd`](#wildfly--service--systemd): Wildfly systemd configuration
* [`wildfly::service::sysvinit`](#wildfly--service--sysvinit): Wildfly sysvinit configuration
* [`wildfly::service::upstart`](#wildfly--service--upstart): Wildfly upstart configuration
* [`wildfly::setup`](#wildfly--setup): Manages Wildfly configuration required to run in service mode.

### Defined types

* [`wildfly::cli`](#wildfly--cli): Executes an arbitrary JBoss-CLI command   `[node-type=node-name (/node-type=node-name)*] : operation-name ['('[name=value [, name=value]*]')'
* [`wildfly::config::app_user`](#wildfly--config--app_user): Manages an Application User (`application-users.properties`) for Wildfly.
* [`wildfly::config::mgmt_user`](#wildfly--config--mgmt_user): Manages a Management User (`mgmt-users.properties`) for Wildfly.
* [`wildfly::config::module`](#wildfly--config--module): Manages a Wildfly module (`$WILDFLY_HOME/modules`).
* [`wildfly::config::user`](#wildfly--config--user): Generic Wildfly user management.
* [`wildfly::config::user_groups`](#wildfly--config--user_groups): Manages groups for a Management User (`mgmt-groups.properties`).
* [`wildfly::config::user_roles`](#wildfly--config--user_roles): Manages roles for an Application User (`application-roles.properties`).
* [`wildfly::datasources::datasource`](#wildfly--datasources--datasource): Configures a datasource
* [`wildfly::datasources::db_property`](#wildfly--datasources--db_property): Configures connection property in a database
* [`wildfly::datasources::driver`](#wildfly--datasources--driver): Configures a driver
* [`wildfly::datasources::xa_datasource`](#wildfly--datasources--xa_datasource): Configures a xa_datasource
* [`wildfly::deployment`](#wildfly--deployment): Manages a deployment (JAR, EAR, WAR) in Wildfly.   This define is a wrapper for `wildfly_deployment` that defaults to your local Wildfly inst
* [`wildfly::domain::server_group`](#wildfly--domain--server_group): Manages a domain server group.
* [`wildfly::host::server_config`](#wildfly--host--server_config): Manages a host server-config. This defined type should be used at a slave machine (considering domain mode). You can use this resource to rem
* [`wildfly::jgroups::stack`](#wildfly--jgroups--stack): Configures jgroups stacks
* [`wildfly::jgroups::stack::tcp`](#wildfly--jgroups--stack--tcp): Configures jgroups TCP-based stacks.
* [`wildfly::jgroups::stack::tcpgossip`](#wildfly--jgroups--stack--tcpgossip): Configures a tcpgossip stack.
* [`wildfly::jgroups::stack::tcpping`](#wildfly--jgroups--stack--tcpping): Configures a tcpping stack.
* [`wildfly::logging::category`](#wildfly--logging--category): Configures a log category
* [`wildfly::messaging::activemq::connection_factory`](#wildfly--messaging--activemq--connection_factory): Configures a connection factory
* [`wildfly::messaging::activemq::queue`](#wildfly--messaging--activemq--queue): Configures a queue
* [`wildfly::messaging::activemq::topic`](#wildfly--messaging--activemq--topic): Configures a topic
* [`wildfly::messaging::queue`](#wildfly--messaging--queue): Configures a queue
* [`wildfly::messaging::topic`](#wildfly--messaging--topic): Configures a topic
* [`wildfly::modcluster::config`](#wildfly--modcluster--config): Configures modcluster subsystem
* [`wildfly::patch::offline`](#wildfly--patch--offline): Applies patches offline.
* [`wildfly::patch::online`](#wildfly--patch--online): Applies patches online. Requires server restart.
* [`wildfly::reload`](#wildfly--reload): Performs a system reload when a reload is required `server-state=reload-required`.   This define is a wrapper for `wildfly_restart` that defa
* [`wildfly::resource`](#wildfly--resource): Manages a Wildfly configuration resource: e.g `/subsystem=datasources/data-source=MyDS or /subsystem=datasources/jdbc-driver=postgresql`.   V
* [`wildfly::restart`](#wildfly--restart): Performs a full restart system when a restart is required `server-state=restart-required`.   This define is a wrapper for `wildfly_restart` t
* [`wildfly::security::domain`](#wildfly--security--domain): This is a defined resource type for creating a security domain Please also see: https://docs.jboss.org/author/display/WFLY9/Security+subsyste
* [`wildfly::security::group_role_mapping`](#wildfly--security--group_role_mapping)
* [`wildfly::security::ldap_realm`](#wildfly--security--ldap_realm): This defined resource configures a (opiniated!!) LDAP security realm.  Based on (among others): - https://access.redhat.com/documentation/en-
* [`wildfly::security::login_module`](#wildfly--security--login_module): This is the login-module configuration for a security domain Multiple login-modules can be specified for a single security domain.  [*domain_
* [`wildfly::security::user_role_mapping`](#wildfly--security--user_role_mapping)
* [`wildfly::system::property`](#wildfly--system--property): Configures a system property
* [`wildfly::undertow::https`](#wildfly--undertow--https): Configures a connector
* [`wildfly::web::connector`](#wildfly--web--connector)
* [`wildfly::web::ssl`](#wildfly--web--ssl)

### Resource types

* [`wildfly_cli`](#wildfly_cli): Executes JBoss-CLI commmands
* [`wildfly_deployment`](#wildfly_deployment): Manages JBoss deployment
* [`wildfly_resource`](#wildfly_resource): Manages JBoss resources like datasources, messaging, ssl, modcluster, etc
* [`wildfly_restart`](#wildfly_restart): Manage JBoss restarts.

### Functions

* [`os_config`](#os_config): Default OS configuration for a specific distribution and version.
* [`wildfly::objectify`](#wildfly--objectify): Converts a LIST of STRINGs and OBJECTs into an OBJECT of OBJECTs.
* [`wildfly::patch_args`](#wildfly--patch_args): Generate args for JBoss-CLI `patch` command.
* [`wildfly::profile_path`](#wildfly--profile_path): Transform a profile name to a JBoss-CLI profile path.
* [`wildfly::service_config`](#wildfly--service_config): Default service configuration for a specific distribution, version   execution mode and initsystem.

### Data types

* [`Wildfly::Config_file`](#Wildfly--Config_file)
* [`Wildfly::Distribution`](#Wildfly--Distribution)
* [`Wildfly::Mode`](#Wildfly--Mode)

## Classes

### <a name="wildfly"></a>`wildfly`

Main class, includes all other classes.

#### Parameters

The following parameters are available in the `wildfly` class:

* [`config`](#-wildfly--config)
* [`conf_file`](#-wildfly--conf_file)
* [`conf_template`](#-wildfly--conf_template)
* [`console_log`](#-wildfly--console_log)
* [`custom_init`](#-wildfly--custom_init)
* [`distribution`](#-wildfly--distribution)
* [`dirname`](#-wildfly--dirname)
* [`domain_config`](#-wildfly--domain_config)
* [`external_facts`](#-wildfly--external_facts)
* [`gid`](#-wildfly--gid)
* [`group`](#-wildfly--group)
* [`host_config`](#-wildfly--host_config)
* [`init_system`](#-wildfly--init_system)
* [`install_cache_dir`](#-wildfly--install_cache_dir)
* [`deploy_cache_dir`](#-wildfly--deploy_cache_dir)
* [`install_download_timeout`](#-wildfly--install_download_timeout)
* [`install_source`](#-wildfly--install_source)
* [`java_home`](#-wildfly--java_home)
* [`java_opts`](#-wildfly--java_opts)
* [`java_xmx`](#-wildfly--java_xmx)
* [`java_xms`](#-wildfly--java_xms)
* [`java_maxmetaspace_size`](#-wildfly--java_maxmetaspace_size)
* [`jboss_opts`](#-wildfly--jboss_opts)
* [`manage_user`](#-wildfly--manage_user)
* [`mgmt_user`](#-wildfly--mgmt_user)
* [`mgmt_create_keystores`](#-wildfly--mgmt_create_keystores)
* [`mgmt_keystore`](#-wildfly--mgmt_keystore)
* [`mgmt_keystore_alias`](#-wildfly--mgmt_keystore_alias)
* [`mgmt_keystore_pass`](#-wildfly--mgmt_keystore_pass)
* [`mgmt_ssl_cert`](#-wildfly--mgmt_ssl_cert)
* [`mgmt_ssl_key`](#-wildfly--mgmt_ssl_key)
* [`mode`](#-wildfly--mode)
* [`mode_template`](#-wildfly--mode_template)
* [`overlay_class`](#-wildfly--overlay_class)
* [`package_ensure`](#-wildfly--package_ensure)
* [`package_name`](#-wildfly--package_name)
* [`package_version`](#-wildfly--package_version)
* [`properties`](#-wildfly--properties)
* [`remote_debug`](#-wildfly--remote_debug)
* [`remote_debug_port`](#-wildfly--remote_debug_port)
* [`remote_username`](#-wildfly--remote_username)
* [`secret_value`](#-wildfly--secret_value)
* [`secure_mgmt_api`](#-wildfly--secure_mgmt_api)
* [`service_ensure`](#-wildfly--service_ensure)
* [`service_enable`](#-wildfly--service_enable)
* [`service_file`](#-wildfly--service_file)
* [`service_name`](#-wildfly--service_name)
* [`service_manage`](#-wildfly--service_manage)
* [`shutdown_wait`](#-wildfly--shutdown_wait)
* [`startup_wait`](#-wildfly--startup_wait)
* [`systemd_template`](#-wildfly--systemd_template)
* [`uid`](#-wildfly--uid)
* [`user`](#-wildfly--user)
* [`user_home`](#-wildfly--user_home)
* [`version`](#-wildfly--version)
* [`process_controller_java_opts`](#-wildfly--process_controller_java_opts)
* [`host_controller_java_opts`](#-wildfly--host_controller_java_opts)

##### <a name="-wildfly--config"></a>`config`

Data type: `Wildfly::Config_file`

Sets Wildfly configuration file for initialization when you're using 'standalone' mode.

Default value: `'standalone.xml'`

##### <a name="-wildfly--conf_file"></a>`conf_file`

Data type: `Optional[Stdlib::Unixpath]`

Sets a file to be used for service configuration.

Default value: `undef`

##### <a name="-wildfly--conf_template"></a>`conf_template`

Data type: `Optional[String]`

Sets a template file for service configuration.

Default value: `undef`

##### <a name="-wildfly--console_log"></a>`console_log`

Data type: `Stdlib::Unixpath`

Configures service log file.

Default value: `'/var/log/wildfly/console.log'`

##### <a name="-wildfly--custom_init"></a>`custom_init`

Data type: `Optional[String]`

Sets a custom init script.

Default value: `undef`

##### <a name="-wildfly--distribution"></a>`distribution`

Data type: `Wildfly::Distribution`

Sets the Wildfly distribution: 'wildfly' or 'jboss-eap'.

Default value: `'wildfly'`

##### <a name="-wildfly--dirname"></a>`dirname`

Data type: `Stdlib::Unixpath`

`JBOSS_HOME`. i.e. The directory where your Wildfly will live.

Default value: `'/opt/wildfly'`

##### <a name="-wildfly--domain_config"></a>`domain_config`

Data type: `Wildfly::Config_file`

Sets Wildfly configuration file for initialization when you're using 'domain' mode.

Default value: `'domain.xml'`

##### <a name="-wildfly--external_facts"></a>`external_facts`

Data type: `Boolean`

Whether it should deploy external facts.

Default value: `false`

##### <a name="-wildfly--gid"></a>`gid`

Data type: `Optional[Integer]`

Sets managed group ID.

Default value: `undef`

##### <a name="-wildfly--group"></a>`group`

Data type: `String`

Group to own `JBOSS_HOME`. If `manage_user` is `true`, this group will be managed.

Default value: `'wildfly'`

##### <a name="-wildfly--host_config"></a>`host_config`

Data type: `Wildfly::Config_file`

Sets Wildfly Host configuration file for initialization when you're using 'domain' mode.

Default value: `'host.xml'`

##### <a name="-wildfly--init_system"></a>`init_system`

Data type: `Enum['sysvinit', 'systemd', 'upstart']`

Sets initsystem for service configuration.

Default value: `$facts['initsystem']`

##### <a name="-wildfly--install_cache_dir"></a>`install_cache_dir`

Data type: `Stdlib::Unixpath`

The directory to be used for wget cache.

Default value: `'/var/cache/wget'`

##### <a name="-wildfly--deploy_cache_dir"></a>`deploy_cache_dir`

Data type: `Stdlib::Unixpath`

The directory to be used for deployment cache.

Default value: `'/opt'`

##### <a name="-wildfly--install_download_timeout"></a>`install_download_timeout`

Data type: `Integer`

Sets the timeout for installer download.

Default value: `500`

##### <a name="-wildfly--install_source"></a>`install_source`

Data type:

```puppet
Variant[Pattern[/^file:\/\//],
    Pattern[/^puppet:\/\//],
    Stdlib::Httpsurl, Stdlib::Httpurl,
    Undef
  ]
```

Custom source of Wildfly tarball installer. Defaults to standard Wildfly repositories.

Default value: `undef`

##### <a name="-wildfly--java_home"></a>`java_home`

Data type: `Stdlib::Unixpath`

Sets the `JAVA_HOME` for Wildfly.

Default value: `'/usr/java/default'`

##### <a name="-wildfly--java_opts"></a>`java_opts`

Data type: `Variant[Undef, String, Array]`

Sets `JAVA_OPTS`, allowing to override several Java params, like `Xmx`, `Xms` and `MaxMetaspaceSize`,

Default value: `undef`

##### <a name="-wildfly--java_xmx"></a>`java_xmx`

Data type: `String`

Sets Java's `-Xmx` parameter.

Default value: `'512m'`

##### <a name="-wildfly--java_xms"></a>`java_xms`

Data type: `String`

Sets Java's `-Xms` parameter.

Default value: `'256m'`

##### <a name="-wildfly--java_maxmetaspace_size"></a>`java_maxmetaspace_size`

Data type: `String`

Sets Java's `-XX:MaxMetaspaceSize` parameter.

Default value: `'128m'`

##### <a name="-wildfly--jboss_opts"></a>`jboss_opts`

Data type: `Optional[String]`

Sets `JBOSS_OPTS`, allowing to override several JBoss properties. It only works with Wildfly 8.2+.

Default value: `undef`

##### <a name="-wildfly--manage_user"></a>`manage_user`

Data type: `Boolean`

Whether this module should manage wildfly user and group.

Default value: `true`

##### <a name="-wildfly--mgmt_user"></a>`mgmt_user`

Data type: `Struct[{ username => String, password => String }]`

Hash containing a Wildfly's management user to be used internally.

Default value:

```puppet
{
    username => 'puppet',
    password => fqdn_rand_string(30),
  }
```

##### <a name="-wildfly--mgmt_create_keystores"></a>`mgmt_create_keystores`

Data type: `Boolean`

Enables or disables the creation of keystores for TLS enabled ManagementRealm.

Default value: `true`

##### <a name="-wildfly--mgmt_keystore"></a>`mgmt_keystore`

Data type: `Stdlib::Unixpath`

Path to a pre-defined keystore to be used for a TLS enabled ManagementRealm.

Default value: `"${dirname}/${mode}/configuration/mgmt.jks"`

##### <a name="-wildfly--mgmt_keystore_alias"></a>`mgmt_keystore_alias`

Data type: `String`

The java keystore 'alias' to be used for a TLS enabled ManagementRealm.

Default value: `'mgmt'`

##### <a name="-wildfly--mgmt_keystore_pass"></a>`mgmt_keystore_pass`

Data type: `String`

The java keystore password to be used for a TLS enabled ManagementRealm.

Default value: `'changeit'`

##### <a name="-wildfly--mgmt_ssl_cert"></a>`mgmt_ssl_cert`

Data type: `Optional[Stdlib::Unixpath]`

Path to the certificate used for setting up the ManagementRealm keystore.

Default value: `undef`

##### <a name="-wildfly--mgmt_ssl_key"></a>`mgmt_ssl_key`

Data type: `Optional[Stdlib::Unixpath]`

Path to the private key used for setting up the ManagementRealm keystore.

Default value: `undef`

##### <a name="-wildfly--mode"></a>`mode`

Data type: `Wildfly::Mode`

Sets Wildfly execution mode will run, 'standalone' or 'domain'.

Default value: `'standalone'`

##### <a name="-wildfly--mode_template"></a>`mode_template`

Data type: `String`

Sets epp template for standalone.conf or domain.conf.

Default value: `"wildfly/${mode}.conf"`

##### <a name="-wildfly--overlay_class"></a>`overlay_class`

Data type: `Optional[String]`

Sets a class to be applied between 'install' and 'setup' classes.

Default value: `undef`

##### <a name="-wildfly--package_ensure"></a>`package_ensure`

Data type: `String`

Wheter it should manage required packages.

Default value: `'present'`

##### <a name="-wildfly--package_name"></a>`package_name`

Data type: `Optional[String]`

Sets Wildfly package name.

Default value: `undef`

##### <a name="-wildfly--package_version"></a>`package_version`

Data type: `Optional[String]`

Sets Wildfly package version.

Default value: `undef`

##### <a name="-wildfly--properties"></a>`properties`

Data type: `Hash[Pattern[/^\w*(\.\w*-?\w*)*$/], String]`

Sets properties for your service.

Default value:

```puppet
{
    'jboss.bind.address' => '0.0.0.0',
    'jboss.bind.address.management' => '127.0.0.1',
    'jboss.management.http.port' => '9990',
    'jboss.management.https.port' => '9993',
    'jboss.http.port' => '8080',
    'jboss.https.port' => '8443',
    'jboss.ajp.port' => '8009',
  }
```

##### <a name="-wildfly--remote_debug"></a>`remote_debug`

Data type: `Boolean`

Whether remote debug should be enabled.

Default value: `false`

##### <a name="-wildfly--remote_debug_port"></a>`remote_debug_port`

Data type: `Integer`

Sets the port to be used by remote debug.

Default value: `8787`

##### <a name="-wildfly--remote_username"></a>`remote_username`

Data type: `Optional[String]`

Sets remote username in host config.

Default value: `undef`

##### <a name="-wildfly--secret_value"></a>`secret_value`

Data type: `Optional[String]`

Sets the secret value in host config.

Default value: `undef`

##### <a name="-wildfly--secure_mgmt_api"></a>`secure_mgmt_api`

Data type: `Boolean`

Setup and use HTTPS calls to the management API.

Default value: `false`

##### <a name="-wildfly--service_ensure"></a>`service_ensure`

Data type: `Boolean`

Sets Wildfly's service 'ensure'.

Default value: `true`

##### <a name="-wildfly--service_enable"></a>`service_enable`

Data type: `Boolean`

Sets Wildfly's service 'enable'.

Default value: `true`

##### <a name="-wildfly--service_file"></a>`service_file`

Data type: `Optional[Stdlib::Unixpath]`

Sets a file to be used for service management.

Default value: `undef`

##### <a name="-wildfly--service_name"></a>`service_name`

Data type: `Optional[String]`

Sets Wildfly's service 'name'.

Default value: `undef`

##### <a name="-wildfly--service_manage"></a>`service_manage`

Data type: `Boolean`

Reload Wildfly's service when changed config.

Default value: `true`

##### <a name="-wildfly--shutdown_wait"></a>`shutdown_wait`

Data type: `Integer`

Sets the time to wait for the process to be shutdown - sysvinit scripts only.

Default value: `30`

##### <a name="-wildfly--startup_wait"></a>`startup_wait`

Data type: `Integer`

Sets the time to wait for the process to be up - sysvinit scripts only.

Default value: `30`

##### <a name="-wildfly--systemd_template"></a>`systemd_template`

Data type: `Optional[String]`

Sets a custom systemd template.

Default value: `undef`

##### <a name="-wildfly--uid"></a>`uid`

Data type: `Optional[Integer]`

Sets managed user ID.

Default value: `undef`

##### <a name="-wildfly--user"></a>`user`

Data type: `String`

User to own `JBOSS_HOME`. If `manage_user` is `true`, this user will be managed.

Default value: `'wildfly'`

##### <a name="-wildfly--user_home"></a>`user_home`

Data type: `Stdlib::Unixpath`

User home directory. Defaults to '/home/wildfly'

Default value: `'/home/wildfly'`

##### <a name="-wildfly--version"></a>`version`

Data type: `Pattern[/^(\d{1,}\.\d{1,}(\.\d{1,})?$)/]`

Sets the Wildfly version managed in order to handle small differences among versions.

Default value: `'9.0.2'`

##### <a name="-wildfly--process_controller_java_opts"></a>`process_controller_java_opts`

Data type: `Variant[Undef, String, Array]`



Default value: `undef`

##### <a name="-wildfly--host_controller_java_opts"></a>`host_controller_java_opts`

Data type: `Variant[Undef, String, Array]`



Default value: `undef`

### <a name="wildfly--external_facts"></a>`wildfly::external_facts`

Set external wildflty facts

### <a name="wildfly--install"></a>`wildfly::install`

Downloads and installs Wildfly from a remote source or a system package.

### <a name="wildfly--prepare"></a>`wildfly::prepare`

Manages Wildfly requirements (user, group, dirs and packages)

### <a name="wildfly--secure_mgmt_api"></a>`wildfly::secure_mgmt_api`

Manages secure management api

### <a name="wildfly--service"></a>`wildfly::service`

Manages Wildfly service.

### <a name="wildfly--service--systemd"></a>`wildfly::service::systemd`

Wildfly systemd configuration

### <a name="wildfly--service--sysvinit"></a>`wildfly::service::sysvinit`

Wildfly sysvinit configuration

### <a name="wildfly--service--upstart"></a>`wildfly::service::upstart`

Wildfly upstart configuration

### <a name="wildfly--setup"></a>`wildfly::setup`

Manages Wildfly configuration required to run in service mode.

## Defined types

### <a name="wildfly--cli"></a>`wildfly::cli`

Executes an arbitrary JBoss-CLI command
  `[node-type=node-name (/node-type=node-name)*] : operation-name ['('[name=value [, name=value]*]')'] [{header (;header)*}]`.
  This define is a wrapper for `wildfly_cli` that defaults to your local Wildfly installation.

#### Parameters

The following parameters are available in the `wildfly::cli` defined type:

* [`command`](#-wildfly--cli--command)
* [`unless`](#-wildfly--cli--unless)
* [`onlyif`](#-wildfly--cli--onlyif)
* [`username`](#-wildfly--cli--username)
* [`password`](#-wildfly--cli--password)
* [`host`](#-wildfly--cli--host)
* [`port`](#-wildfly--cli--port)
* [`secure`](#-wildfly--cli--secure)
* [`refreshonly`](#-wildfly--cli--refreshonly)

##### <a name="-wildfly--cli--command"></a>`command`

Data type: `String`

The actual command to execute.

Default value: `$title`

##### <a name="-wildfly--cli--unless"></a>`unless`

Data type: `Optional[String]`

If this parameter is set, then this `cli` will only run if this command condition is met.

Default value: `undef`

##### <a name="-wildfly--cli--onlyif"></a>`onlyif`

Data type: `Optional[String]`

If this parameter is set, then this `cli` will run unless this command condition is met.

Default value: `undef`

##### <a name="-wildfly--cli--username"></a>`username`

Data type: `String`

Wildfly's management user to be used internally.

Default value: `$wildfly::mgmt_user['username']`

##### <a name="-wildfly--cli--password"></a>`password`

Data type: `String`

The password for Wildfly's management user.

Default value: `$wildfly::mgmt_user['password']`

##### <a name="-wildfly--cli--host"></a>`host`

Data type: `String`

The IP address or FQDN of the JBoss Management service.

Default value: `$wildfly::properties['jboss.bind.address.management']`

##### <a name="-wildfly--cli--port"></a>`port`

Data type: `String`

The port of the JBoss Management service.

Default value: `$wildfly::properties['jboss.management.http.port']`

##### <a name="-wildfly--cli--secure"></a>`secure`

Data type: `Boolean`

Use https port or http port.

Default value: `$wildfly::secure_mgmt_api`

##### <a name="-wildfly--cli--refreshonly"></a>`refreshonly`

Data type: `Optional[Boolean]`



Default value: `undef`

### <a name="wildfly--config--app_user"></a>`wildfly::config::app_user`

Manages an Application User (`application-users.properties`) for Wildfly.

#### Parameters

The following parameters are available in the `wildfly::config::app_user` defined type:

* [`password`](#-wildfly--config--app_user--password)

##### <a name="-wildfly--config--app_user--password"></a>`password`

Data type: `String`

The user password.

### <a name="wildfly--config--mgmt_user"></a>`wildfly::config::mgmt_user`

Manages a Management User (`mgmt-users.properties`) for Wildfly.

#### Parameters

The following parameters are available in the `wildfly::config::mgmt_user` defined type:

* [`password`](#-wildfly--config--mgmt_user--password)

##### <a name="-wildfly--config--mgmt_user--password"></a>`password`

Data type: `String`

The user password.

### <a name="wildfly--config--module"></a>`wildfly::config::module`

Manages a Wildfly module (`$WILDFLY_HOME/modules`).

#### Parameters

The following parameters are available in the `wildfly::config::module` defined type:

* [`source`](#-wildfly--config--module--source)
* [`template`](#-wildfly--config--module--template)
* [`dependencies`](#-wildfly--config--module--dependencies)
* [`system`](#-wildfly--config--module--system)
* [`custom_file`](#-wildfly--config--module--custom_file)

##### <a name="-wildfly--config--module--source"></a>`source`

Data type:

```puppet
Variant[
    Pattern[/^\./],
    Pattern[/^file:\/\//],
    Pattern[/^puppet:\/\//],
    Stdlib::Httpsurl,
    Stdlib::Httpurl
  ]
```

Sets the source for this module, either a local file `file://`, a remote one `http://` or `puppet://`.

##### <a name="-wildfly--config--module--template"></a>`template`

Data type: `String`

Sets the EPP template to module.xml file. Default to 'wildfly/module.xml'.

Default value: `'wildfly/module.xml'`

##### <a name="-wildfly--config--module--dependencies"></a>`dependencies`

Data type: `Array`

Sets the dependencies for this module e.g. `javax.transaction`.

Default value: `[]`

##### <a name="-wildfly--config--module--system"></a>`system`

Data type: `Boolean`

Whether this is a system (`system/layers/base`) module or not.

Default value: `true`

##### <a name="-wildfly--config--module--custom_file"></a>`custom_file`

Data type: `Optional[String]`

Sets a file source for module.xml. If set, template is ignored.

Default value: `undef`

### <a name="wildfly--config--user"></a>`wildfly::config::user`

Generic Wildfly user management.

#### Parameters

The following parameters are available in the `wildfly::config::user` defined type:

* [`password`](#-wildfly--config--user--password)
* [`file_name`](#-wildfly--config--user--file_name)

##### <a name="-wildfly--config--user--password"></a>`password`

Data type: `String`

User password.

##### <a name="-wildfly--config--user--file_name"></a>`file_name`

Data type: `String`

Name of config file.

### <a name="wildfly--config--user_groups"></a>`wildfly::config::user_groups`

Manages groups for a Management User (`mgmt-groups.properties`).

#### Parameters

The following parameters are available in the `wildfly::config::user_groups` defined type:

* [`groups`](#-wildfly--config--user_groups--groups)

##### <a name="-wildfly--config--user_groups--groups"></a>`groups`

Data type: `String`

List of groups to associate with this user.

### <a name="wildfly--config--user_roles"></a>`wildfly::config::user_roles`

Manages roles for an Application User (`application-roles.properties`).

#### Parameters

The following parameters are available in the `wildfly::config::user_roles` defined type:

* [`roles`](#-wildfly--config--user_roles--roles)

##### <a name="-wildfly--config--user_roles--roles"></a>`roles`

Data type: `String`

List of roles to associate with this user.

### <a name="wildfly--datasources--datasource"></a>`wildfly::datasources::datasource`

Configures a datasource

#### Parameters

The following parameters are available in the `wildfly::datasources::datasource` defined type:

* [`config`](#-wildfly--datasources--datasource--config)
* [`target_profile`](#-wildfly--datasources--datasource--target_profile)

##### <a name="-wildfly--datasources--datasource--config"></a>`config`

Data type: `Optional[Hash]`

datasource config

Default value: `undef`

##### <a name="-wildfly--datasources--datasource--target_profile"></a>`target_profile`

Data type: `Optional[String]`

for domain mode you need to set this parameter

Default value: `undef`

### <a name="wildfly--datasources--db_property"></a>`wildfly::datasources::db_property`

Configures connection property in a database

#### Parameters

The following parameters are available in the `wildfly::datasources::db_property` defined type:

* [`database`](#-wildfly--datasources--db_property--database)
* [`value`](#-wildfly--datasources--db_property--value)
* [`target_profile`](#-wildfly--datasources--db_property--target_profile)

##### <a name="-wildfly--datasources--db_property--database"></a>`database`

Data type: `String`

datasource database

##### <a name="-wildfly--datasources--db_property--value"></a>`value`

Data type: `Optional[String]`

datasource db property value

Default value: `undef`

##### <a name="-wildfly--datasources--db_property--target_profile"></a>`target_profile`

Data type: `Optional[String]`

for domain mode you need to set this parameter

Default value: `undef`

### <a name="wildfly--datasources--driver"></a>`wildfly::datasources::driver`

Configures a driver

#### Parameters

The following parameters are available in the `wildfly::datasources::driver` defined type:

* [`driver_name`](#-wildfly--datasources--driver--driver_name)
* [`driver_module_name`](#-wildfly--datasources--driver--driver_module_name)
* [`driver_class_name`](#-wildfly--datasources--driver--driver_class_name)
* [`driver_xa_datasource_class_name`](#-wildfly--datasources--driver--driver_xa_datasource_class_name)
* [`target_profile`](#-wildfly--datasources--driver--target_profile)

##### <a name="-wildfly--datasources--driver--driver_name"></a>`driver_name`

Data type: `String`

datasource driver

##### <a name="-wildfly--datasources--driver--driver_module_name"></a>`driver_module_name`

Data type: `String`

datasource driver module name

##### <a name="-wildfly--datasources--driver--driver_class_name"></a>`driver_class_name`

Data type: `Optional[String]`

datasource driver class name

Default value: `undef`

##### <a name="-wildfly--datasources--driver--driver_xa_datasource_class_name"></a>`driver_xa_datasource_class_name`

Data type: `Optional[String]`

datasource driver xa class name

Default value: `undef`

##### <a name="-wildfly--datasources--driver--target_profile"></a>`target_profile`

Data type: `Optional[String]`

for domain mode you need to set this parameter

Default value: `undef`

### <a name="wildfly--datasources--xa_datasource"></a>`wildfly::datasources::xa_datasource`

Configures a xa_datasource

#### Parameters

The following parameters are available in the `wildfly::datasources::xa_datasource` defined type:

* [`config`](#-wildfly--datasources--xa_datasource--config)
* [`target_profile`](#-wildfly--datasources--xa_datasource--target_profile)

##### <a name="-wildfly--datasources--xa_datasource--config"></a>`config`

Data type: `Optional[Hash]`

xa_datasource config

Default value: `undef`

##### <a name="-wildfly--datasources--xa_datasource--target_profile"></a>`target_profile`

Data type: `Optional[String]`

for domain mode you need to set this parameter

Default value: `undef`

### <a name="wildfly--deployment"></a>`wildfly::deployment`

Manages a deployment (JAR, EAR, WAR) in Wildfly.
  This define is a wrapper for `wildfly_deployment` that defaults to your local Wildfly installation.

#### Parameters

The following parameters are available in the `wildfly::deployment` defined type:

* [`ensure`](#-wildfly--deployment--ensure)
* [`source`](#-wildfly--deployment--source)
* [`timeout`](#-wildfly--deployment--timeout)
* [`server_group`](#-wildfly--deployment--server_group)
* [`operation_headers`](#-wildfly--deployment--operation_headers)
* [`username`](#-wildfly--deployment--username)
* [`password`](#-wildfly--deployment--password)
* [`host`](#-wildfly--deployment--host)
* [`port`](#-wildfly--deployment--port)
* [`secure`](#-wildfly--deployment--secure)

##### <a name="-wildfly--deployment--ensure"></a>`ensure`

Data type: `Enum[present, absent]`

Whether the deployment should exist (`present`) or not (`absent`).

Default value: `present`

##### <a name="-wildfly--deployment--source"></a>`source`

Data type:

```puppet
Variant[
    Pattern[/^file:\/\//],
    Pattern[/^puppet:\/\//],
    Stdlib::Httpsurl,
    Stdlib::Httpurl
  ]
```

Sets the source for this deployment, either a local file `file://` or a remote file `http://`.

##### <a name="-wildfly--deployment--timeout"></a>`timeout`

Data type: `Optional[Integer]`

Sets the timeout to deploy this resource.

Default value: `undef`

##### <a name="-wildfly--deployment--server_group"></a>`server_group`

Data type: `Optional[String]`

Sets the target `server-group` for this deployment.

Default value: `undef`

##### <a name="-wildfly--deployment--operation_headers"></a>`operation_headers`

Data type: `Hash`

Sets [operation-headers](https://docs.jboss.org/author/display/WFLY9/Admin+Guide#AdminGuide-OperationHeaders) (e.g. `{ 'allow-resource-service-restart' => true, 'rollback-on-runtime-failure' => false, 'blocking-timeout' => 600}`) to be used when creating/destroying this deployment.

Default value: `{}`

##### <a name="-wildfly--deployment--username"></a>`username`

Data type: `String`

Wildfly's management user to be used internally.

Default value: `$wildfly::mgmt_user['username']`

##### <a name="-wildfly--deployment--password"></a>`password`

Data type: `String`

The password for Wildfly's management user.

Default value: `$wildfly::mgmt_user['password']`

##### <a name="-wildfly--deployment--host"></a>`host`

Data type: `String`

The IP address or FQDN of the JBoss Management service.

Default value: `$wildfly::properties['jboss.bind.address.management']`

##### <a name="-wildfly--deployment--port"></a>`port`

Data type: `String`

The port of the JBoss Management service.

Default value: `$wildfly::properties['jboss.management.http.port']`

##### <a name="-wildfly--deployment--secure"></a>`secure`

Data type: `Boolean`

Use https port or http port.

Default value: `$wildfly::secure_mgmt_api`

### <a name="wildfly--domain--server_group"></a>`wildfly::domain::server_group`

Manages a domain server group.

#### Parameters

The following parameters are available in the `wildfly::domain::server_group` defined type:

* [`ensure`](#-wildfly--domain--server_group--ensure)
* [`profile`](#-wildfly--domain--server_group--profile)
* [`socket_binding_group`](#-wildfly--domain--server_group--socket_binding_group)
* [`socket_binding_port_offset`](#-wildfly--domain--server_group--socket_binding_port_offset)
* [`jvm_name`](#-wildfly--domain--server_group--jvm_name)
* [`jvm_config`](#-wildfly--domain--server_group--jvm_config)

##### <a name="-wildfly--domain--server_group--ensure"></a>`ensure`

Data type: `Enum[present, absent]`

Whether the resource should exist (`present`) or not (`absent`).

Default value: `present`

##### <a name="-wildfly--domain--server_group--profile"></a>`profile`

Data type: `Optional[String]`

Sets profile referenced by the server-group.

Default value: `undef`

##### <a name="-wildfly--domain--server_group--socket_binding_group"></a>`socket_binding_group`

Data type: `Optional[String]`

Sets socket-binding-group referenced by the server-group.

Default value: `undef`

##### <a name="-wildfly--domain--server_group--socket_binding_port_offset"></a>`socket_binding_port_offset`

Data type: `Integer`

Sets socket-binding-port-offset server-config port offset.

Default value: `0`

##### <a name="-wildfly--domain--server_group--jvm_name"></a>`jvm_name`

Data type: `String`

Sets jvm name configured to the server-group.

Default value: `'default'`

##### <a name="-wildfly--domain--server_group--jvm_config"></a>`jvm_config`

Data type: `Hash`

Sets jvm configurations like ``, `` etc.

Default value: `{}`

### <a name="wildfly--host--server_config"></a>`wildfly::host::server_config`

Manages a host server-config. This defined type should be used at a slave machine (considering domain mode).
You can use this resource to remove default servers server-one and server-two (present at default host-slave.xml).
If you removed the default server-groups in the domain controller (main-server-group and other-server-group) you'll
need to ensure that the resources are applied after the Wildfly installation and before the module starts to setup
Wildfly to enable and run the service (or the host controller service will not run at all because the servers are
associated to server-groups that doesn't exist).
For this case, use a overlay_class (wildfly::overlay_class param) or the following snippet:

wildfly::host::server_config { ['server-one', 'server-two']:
  ensure   => absent,
  hostname => $hostname,
  username => $username,
  password => $password,
  require  => Class['wildfly::install'],
  before   => Class['wildfly::setup'],
}

#### Parameters

The following parameters are available in the `wildfly::host::server_config` defined type:

* [`ensure`](#-wildfly--host--server_config--ensure)
* [`server_group`](#-wildfly--host--server_config--server_group)
* [`offset`](#-wildfly--host--server_config--offset)
* [`auto_start`](#-wildfly--host--server_config--auto_start)
* [`wildfly_dir`](#-wildfly--host--server_config--wildfly_dir)
* [`host_config`](#-wildfly--host--server_config--host_config)
* [`hostname`](#-wildfly--host--server_config--hostname)
* [`username`](#-wildfly--host--server_config--username)
* [`password`](#-wildfly--host--server_config--password)
* [`controller_address`](#-wildfly--host--server_config--controller_address)
* [`controller_mgmt_port`](#-wildfly--host--server_config--controller_mgmt_port)
* [`start_server_after_created`](#-wildfly--host--server_config--start_server_after_created)

##### <a name="-wildfly--host--server_config--ensure"></a>`ensure`

Data type: `Enum[present, absent]`

Whether the resource should exist (`present`) or not (`absent`).

Default value: `present`

##### <a name="-wildfly--host--server_config--server_group"></a>`server_group`

Data type: `Optional[String]`

Sets server-group associated to server-config.

Default value: `undef`

##### <a name="-wildfly--host--server_config--offset"></a>`offset`

Data type: `Integer`

Sets server-config port offset.

Default value: `0`

##### <a name="-wildfly--host--server_config--auto_start"></a>`auto_start`

Data type: `Boolean`

Sets server to autostart with JBoss Service.

Default value: `true`

##### <a name="-wildfly--host--server_config--wildfly_dir"></a>`wildfly_dir`

Data type: `Stdlib::Unixpath`

`JBOSS_HOME`. i.e. The directory where your Wildfly will live.

Default value: `$wildfly::dirname`

##### <a name="-wildfly--host--server_config--host_config"></a>`host_config`

Data type: `Optional[Wildfly::Config_file]`

Sets Wildfly Host configuration file used for initialization in 'domain' mode.

Default value: `$wildfly::host_config`

##### <a name="-wildfly--host--server_config--hostname"></a>`hostname`

Data type: `Optional[String]`

Name used to identify host using JBoss CLI (/host=${hostname}).

Default value: `undef`

##### <a name="-wildfly--host--server_config--username"></a>`username`

Data type: `Optional[String]`

Username to connect to domain controller.

Default value: `undef`

##### <a name="-wildfly--host--server_config--password"></a>`password`

Data type: `Optional[String]`

Password to connect to domain controller.

Default value: `undef`

##### <a name="-wildfly--host--server_config--controller_address"></a>`controller_address`

Data type: `Optional[String]`

Domain controller address where the host will connect to configure the server-config.

Default value: `$wildfly::properties['jboss.domain.master.address']`

##### <a name="-wildfly--host--server_config--controller_mgmt_port"></a>`controller_mgmt_port`

Data type: `Integer`

Sets domain controller management port.

Default value: `9990`

##### <a name="-wildfly--host--server_config--start_server_after_created"></a>`start_server_after_created`

Data type: `Boolean`

Sets if the server should be started right after created.

Default value: `true`

### <a name="wildfly--jgroups--stack"></a>`wildfly::jgroups::stack`

Configures jgroups stacks

#### Parameters

The following parameters are available in the `wildfly::jgroups::stack` defined type:

* [`protocols`](#-wildfly--jgroups--stack--protocols)
* [`transport`](#-wildfly--jgroups--stack--transport)

##### <a name="-wildfly--jgroups--stack--protocols"></a>`protocols`

Data type: `Array[Variant[Hash, String]]`

List of protocols to use

##### <a name="-wildfly--jgroups--stack--transport"></a>`transport`

Data type: `Hash`

Transport config hash.

### <a name="wildfly--jgroups--stack--tcp"></a>`wildfly::jgroups::stack::tcp`

Configures jgroups TCP-based stacks.

#### Parameters

The following parameters are available in the `wildfly::jgroups::stack::tcp` defined type:

* [`properties`](#-wildfly--jgroups--stack--tcp--properties)

##### <a name="-wildfly--jgroups--stack--tcp--properties"></a>`properties`

Data type: `Hash`

TCP properties hash.

### <a name="wildfly--jgroups--stack--tcpgossip"></a>`wildfly::jgroups::stack::tcpgossip`

Configures a tcpgossip stack.

#### Parameters

The following parameters are available in the `wildfly::jgroups::stack::tcpgossip` defined type:

* [`initial_hosts`](#-wildfly--jgroups--stack--tcpgossip--initial_hosts)
* [`num_initial_members`](#-wildfly--jgroups--stack--tcpgossip--num_initial_members)
* [`timeout`](#-wildfly--jgroups--stack--tcpgossip--timeout)

##### <a name="-wildfly--jgroups--stack--tcpgossip--initial_hosts"></a>`initial_hosts`

Data type: `String`

Comma delimited list of hosts to be contacted for initial membership.

##### <a name="-wildfly--jgroups--stack--tcpgossip--num_initial_members"></a>`num_initial_members`

Data type: `Integer`

Number of initial members.

##### <a name="-wildfly--jgroups--stack--tcpgossip--timeout"></a>`timeout`

Data type: `Integer`

Max time for socket creation. Default is 3000 msec.

Default value: `3000`

### <a name="wildfly--jgroups--stack--tcpping"></a>`wildfly::jgroups::stack::tcpping`

Configures a tcpping stack.

#### Parameters

The following parameters are available in the `wildfly::jgroups::stack::tcpping` defined type:

* [`initial_hosts`](#-wildfly--jgroups--stack--tcpping--initial_hosts)
* [`num_initial_members`](#-wildfly--jgroups--stack--tcpping--num_initial_members)
* [`timeout`](#-wildfly--jgroups--stack--tcpping--timeout)
* [`port_range`](#-wildfly--jgroups--stack--tcpping--port_range)

##### <a name="-wildfly--jgroups--stack--tcpping--initial_hosts"></a>`initial_hosts`

Data type: `String`

Comma delimited list of hosts to be contacted for initial membership.

##### <a name="-wildfly--jgroups--stack--tcpping--num_initial_members"></a>`num_initial_members`

Data type: `Integer`

Number of initial members.

##### <a name="-wildfly--jgroups--stack--tcpping--timeout"></a>`timeout`

Data type: `Integer`

Max time for socket creation. Default is 3000 msec.

Default value: `3000`

##### <a name="-wildfly--jgroups--stack--tcpping--port_range"></a>`port_range`

Data type: `Integer`

Number of additional ports to be probed for membership.
A port_range of 0 does not probe additional ports.
Example: initial_hosts=A[7800] port_range=0 probes A:7800, port_range=1 probes A:7800 and A:7801.

Default value: `0`

### <a name="wildfly--logging--category"></a>`wildfly::logging::category`

Configures a log category

#### Parameters

The following parameters are available in the `wildfly::logging::category` defined type:

* [`level`](#-wildfly--logging--category--level)
* [`use_parent_handlers`](#-wildfly--logging--category--use_parent_handlers)
* [`handlers`](#-wildfly--logging--category--handlers)
* [`target_profile`](#-wildfly--logging--category--target_profile)

##### <a name="-wildfly--logging--category--level"></a>`level`

Data type: `Enum['DEBUG', 'INFO', 'ERROR']`

Log level

Default value: `'INFO'`

##### <a name="-wildfly--logging--category--use_parent_handlers"></a>`use_parent_handlers`

Data type: `Boolean`

Wheter to use parent handlers or not

Default value: `false`

##### <a name="-wildfly--logging--category--handlers"></a>`handlers`

Data type: `Optional[Array[String[1]]]`

List of log handlers to use

Default value: `undef`

##### <a name="-wildfly--logging--category--target_profile"></a>`target_profile`

Data type: `Optional[String]`

For domain mode you need to set this parameter

Default value: `undef`

### <a name="wildfly--messaging--activemq--connection_factory"></a>`wildfly::messaging::activemq::connection_factory`

Configures a connection factory

#### Parameters

The following parameters are available in the `wildfly::messaging::activemq::connection_factory` defined type:

* [`entries`](#-wildfly--messaging--activemq--connection_factory--entries)
* [`connectors`](#-wildfly--messaging--activemq--connection_factory--connectors)
* [`target_profile`](#-wildfly--messaging--activemq--connection_factory--target_profile)

##### <a name="-wildfly--messaging--activemq--connection_factory--entries"></a>`entries`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--messaging--activemq--connection_factory--connectors"></a>`connectors`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--messaging--activemq--connection_factory--target_profile"></a>`target_profile`

Data type: `Any`



Default value: `undef`

### <a name="wildfly--messaging--activemq--queue"></a>`wildfly::messaging::activemq::queue`

Configures a queue

#### Parameters

The following parameters are available in the `wildfly::messaging::activemq::queue` defined type:

* [`entries`](#-wildfly--messaging--activemq--queue--entries)
* [`durable`](#-wildfly--messaging--activemq--queue--durable)
* [`selector`](#-wildfly--messaging--activemq--queue--selector)
* [`target_profile`](#-wildfly--messaging--activemq--queue--target_profile)

##### <a name="-wildfly--messaging--activemq--queue--entries"></a>`entries`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--messaging--activemq--queue--durable"></a>`durable`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--messaging--activemq--queue--selector"></a>`selector`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--messaging--activemq--queue--target_profile"></a>`target_profile`

Data type: `Any`



Default value: `undef`

### <a name="wildfly--messaging--activemq--topic"></a>`wildfly::messaging::activemq::topic`

Configures a topic

#### Parameters

The following parameters are available in the `wildfly::messaging::activemq::topic` defined type:

* [`entries`](#-wildfly--messaging--activemq--topic--entries)
* [`target_profile`](#-wildfly--messaging--activemq--topic--target_profile)

##### <a name="-wildfly--messaging--activemq--topic--entries"></a>`entries`

Data type: `Any`



##### <a name="-wildfly--messaging--activemq--topic--target_profile"></a>`target_profile`

Data type: `Any`



Default value: `undef`

### <a name="wildfly--messaging--queue"></a>`wildfly::messaging::queue`

Configures a queue

#### Parameters

The following parameters are available in the `wildfly::messaging::queue` defined type:

* [`entries`](#-wildfly--messaging--queue--entries)
* [`durable`](#-wildfly--messaging--queue--durable)
* [`selector`](#-wildfly--messaging--queue--selector)
* [`target_profile`](#-wildfly--messaging--queue--target_profile)

##### <a name="-wildfly--messaging--queue--entries"></a>`entries`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--messaging--queue--durable"></a>`durable`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--messaging--queue--selector"></a>`selector`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--messaging--queue--target_profile"></a>`target_profile`

Data type: `Any`



Default value: `undef`

### <a name="wildfly--messaging--topic"></a>`wildfly::messaging::topic`

Configures a topic

#### Parameters

The following parameters are available in the `wildfly::messaging::topic` defined type:

* [`entries`](#-wildfly--messaging--topic--entries)
* [`target_profile`](#-wildfly--messaging--topic--target_profile)

##### <a name="-wildfly--messaging--topic--entries"></a>`entries`

Data type: `Any`



##### <a name="-wildfly--messaging--topic--target_profile"></a>`target_profile`

Data type: `Any`



Default value: `undef`

### <a name="wildfly--modcluster--config"></a>`wildfly::modcluster::config`

Configures modcluster subsystem

#### Parameters

The following parameters are available in the `wildfly::modcluster::config` defined type:

* [`advertise_socket`](#-wildfly--modcluster--config--advertise_socket)
* [`connector`](#-wildfly--modcluster--config--connector)
* [`type`](#-wildfly--modcluster--config--type)
* [`excluded_contexts`](#-wildfly--modcluster--config--excluded_contexts)
* [`balancer`](#-wildfly--modcluster--config--balancer)
* [`load_balancing_group`](#-wildfly--modcluster--config--load_balancing_group)
* [`proxy_list`](#-wildfly--modcluster--config--proxy_list)
* [`proxies`](#-wildfly--modcluster--config--proxies)
* [`proxy_url`](#-wildfly--modcluster--config--proxy_url)
* [`sticky_session`](#-wildfly--modcluster--config--sticky_session)
* [`target_profile`](#-wildfly--modcluster--config--target_profile)

##### <a name="-wildfly--modcluster--config--advertise_socket"></a>`advertise_socket`

Data type: `Any`



Default value: `'modcluster'`

##### <a name="-wildfly--modcluster--config--connector"></a>`connector`

Data type: `Any`



Default value: `'ajp'`

##### <a name="-wildfly--modcluster--config--type"></a>`type`

Data type: `Any`



Default value: `'busyness'`

##### <a name="-wildfly--modcluster--config--excluded_contexts"></a>`excluded_contexts`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--modcluster--config--balancer"></a>`balancer`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--modcluster--config--load_balancing_group"></a>`load_balancing_group`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--modcluster--config--proxy_list"></a>`proxy_list`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--modcluster--config--proxies"></a>`proxies`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--modcluster--config--proxy_url"></a>`proxy_url`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--modcluster--config--sticky_session"></a>`sticky_session`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--modcluster--config--target_profile"></a>`target_profile`

Data type: `Any`



Default value: `undef`

### <a name="wildfly--patch--offline"></a>`wildfly::patch::offline`

Applies patches offline.

#### Parameters

The following parameters are available in the `wildfly::patch::offline` defined type:

* [`source`](#-wildfly--patch--offline--source)
* [`override_all`](#-wildfly--patch--offline--override_all)
* [`override`](#-wildfly--patch--offline--override)
* [`preserve`](#-wildfly--patch--offline--preserve)

##### <a name="-wildfly--patch--offline--source"></a>`source`

Data type: `Stdlib::Unixpath`

path to patch file.

##### <a name="-wildfly--patch--offline--override_all"></a>`override_all`

Data type: `Boolean`

Whether it should solve all conflicts by overriding current files.

Default value: `false`

##### <a name="-wildfly--patch--offline--override"></a>`override`

Data type: `Array`

List of files to be overridden.

Default value: `[]`

##### <a name="-wildfly--patch--offline--preserve"></a>`preserve`

Data type: `Array`

List of files to be preserved.

Default value: `[]`

### <a name="wildfly--patch--online"></a>`wildfly::patch::online`

Applies patches online. Requires server restart.

#### Parameters

The following parameters are available in the `wildfly::patch::online` defined type:

* [`source`](#-wildfly--patch--online--source)
* [`override_all`](#-wildfly--patch--online--override_all)
* [`override`](#-wildfly--patch--online--override)
* [`preserve`](#-wildfly--patch--online--preserve)

##### <a name="-wildfly--patch--online--source"></a>`source`

Data type: `Stdlib::Unixpath`

path to patch file.

##### <a name="-wildfly--patch--online--override_all"></a>`override_all`

Data type: `Boolean`

Whether it should solve all conflicts by overriding current files.

Default value: `false`

##### <a name="-wildfly--patch--online--override"></a>`override`

Data type: `Array`

List of files to be overridden.

Default value: `[]`

##### <a name="-wildfly--patch--online--preserve"></a>`preserve`

Data type: `Array`

List of files to be preserved.

Default value: `[]`

### <a name="wildfly--reload"></a>`wildfly::reload`

Performs a system reload when a reload is required `server-state=reload-required`.
  This define is a wrapper for `wildfly_restart` that defaults to your local Wildfly installation.
  It is commonly used as a subscriber of a resource that requires reload.

#### Parameters

The following parameters are available in the `wildfly::reload` defined type:

* [`retries`](#-wildfly--reload--retries)
* [`wait`](#-wildfly--reload--wait)
* [`username`](#-wildfly--reload--username)
* [`password`](#-wildfly--reload--password)
* [`host`](#-wildfly--reload--host)
* [`port`](#-wildfly--reload--port)
* [`secure`](#-wildfly--reload--secure)

##### <a name="-wildfly--reload--retries"></a>`retries`

Data type: `Integer`

Sets the number of retries to check if service is available.

Default value: `3`

##### <a name="-wildfly--reload--wait"></a>`wait`

Data type: `Integer`

Sets the amount of time in seconds that this resource will wait for the service to be available before a attempt.

Default value: `10`

##### <a name="-wildfly--reload--username"></a>`username`

Data type: `String`

Wildfly's management user to be used internally.

Default value: `$wildfly::mgmt_user['username']`

##### <a name="-wildfly--reload--password"></a>`password`

Data type: `String`

The password for Wildfly's management user.

Default value: `$wildfly::mgmt_user['password']`

##### <a name="-wildfly--reload--host"></a>`host`

Data type: `String`

The IP address or FQDN of the JBoss Management service.

Default value: `$wildfly::properties['jboss.bind.address.management']`

##### <a name="-wildfly--reload--port"></a>`port`

Data type: `String`

The port of the JBoss Management service.

Default value: `$wildfly::properties['jboss.management.http.port']`

##### <a name="-wildfly--reload--secure"></a>`secure`

Data type: `Boolean`

Use https port or http port.

Default value: `$wildfly::secure_mgmt_api`

### <a name="wildfly--resource"></a>`wildfly::resource`

Manages a Wildfly configuration resource: e.g `/subsystem=datasources/data-source=MyDS or /subsystem=datasources/jdbc-driver=postgresql`.
  Virtually anything in your configuration XML file that can be manipulated using JBoss-CLI could be managed by this defined type.
  This define is a wrapper for `wildfly_resource` that defaults to your local Wildfly installation.

#### Parameters

The following parameters are available in the `wildfly::resource` defined type:

* [`ensure`](#-wildfly--resource--ensure)
* [`recursive`](#-wildfly--resource--recursive)
* [`undefine_attributes`](#-wildfly--resource--undefine_attributes)
* [`content`](#-wildfly--resource--content)
* [`operation_headers`](#-wildfly--resource--operation_headers)
* [`profile`](#-wildfly--resource--profile)
* [`username`](#-wildfly--resource--username)
* [`password`](#-wildfly--resource--password)
* [`host`](#-wildfly--resource--host)
* [`port`](#-wildfly--resource--port)
* [`secure`](#-wildfly--resource--secure)

##### <a name="-wildfly--resource--ensure"></a>`ensure`

Data type: `Enum[present, absent]`

Whether the resource should exist (`present`) or not (`absent`).

Default value: `present`

##### <a name="-wildfly--resource--recursive"></a>`recursive`

Data type: `Boolean`

Whether it should manage the resource recursively or not.

Default value: `false`

##### <a name="-wildfly--resource--undefine_attributes"></a>`undefine_attributes`

Data type: `Boolean`

Whether it should undefine attributes with undef value.

Default value: `false`

##### <a name="-wildfly--resource--content"></a>`content`

Data type: `Hash`

Sets the content/state of the target resource.

Default value: `{}`

##### <a name="-wildfly--resource--operation_headers"></a>`operation_headers`

Data type: `Hash`

Sets [operation-headers](https://docs.jboss.org/author/display/WFLY9/Admin+Guide#AdminGuide-OperationHeaders) (e.g. `{ 'allow-resource-service-restart' => true, 'rollback-on-runtime-failure' => false, 'blocking-timeout' => 600}`) to be used when creating/destroying this resource.

Default value: `{}`

##### <a name="-wildfly--resource--profile"></a>`profile`

Data type: `Optional[String]`

Sets the target profile to prefix resource name. Requires domain mode.

Default value: `undef`

##### <a name="-wildfly--resource--username"></a>`username`

Data type: `String`

Wildfly's management user to be used internally.

Default value: `$wildfly::mgmt_user['username']`

##### <a name="-wildfly--resource--password"></a>`password`

Data type: `String`

The password for Wildfly's management user.

Default value: `$wildfly::mgmt_user['password']`

##### <a name="-wildfly--resource--host"></a>`host`

Data type: `String`

The IP address or FQDN of the JBoss Management service.

Default value: `$wildfly::properties['jboss.bind.address.management']`

##### <a name="-wildfly--resource--port"></a>`port`

Data type: `String`

The port of the JBoss Management service.

Default value: `$wildfly::properties['jboss.management.http.port']`

##### <a name="-wildfly--resource--secure"></a>`secure`

Data type: `Boolean`

Use https port or http port.

Default value: `$wildfly::secure_mgmt_api`

### <a name="wildfly--restart"></a>`wildfly::restart`

Performs a full restart system when a restart is required `server-state=restart-required`.
  This define is a wrapper for `wildfly_restart` that defaults to your local Wildfly installation.
  It is commonly used as a subscriber of a resource that requires restart.

#### Parameters

The following parameters are available in the `wildfly::restart` defined type:

* [`retries`](#-wildfly--restart--retries)
* [`wait`](#-wildfly--restart--wait)
* [`username`](#-wildfly--restart--username)
* [`password`](#-wildfly--restart--password)
* [`host`](#-wildfly--restart--host)
* [`port`](#-wildfly--restart--port)
* [`secure`](#-wildfly--restart--secure)

##### <a name="-wildfly--restart--retries"></a>`retries`

Data type: `Integer`

Sets the number of retries to check if service is available.

Default value: `3`

##### <a name="-wildfly--restart--wait"></a>`wait`

Data type: `Integer`

Sets the amount of time in seconds that this resource will wait for the service to be available before a attempt.

Default value: `20`

##### <a name="-wildfly--restart--username"></a>`username`

Data type: `String`

Wildfly's management user to be used internally.

Default value: `$wildfly::mgmt_user['username']`

##### <a name="-wildfly--restart--password"></a>`password`

Data type: `String`

The password for Wildfly's management user.

Default value: `$wildfly::mgmt_user['password']`

##### <a name="-wildfly--restart--host"></a>`host`

Data type: `String`

The IP address or FQDN of the JBoss Management service.

Default value: `$wildfly::properties['jboss.bind.address.management']`

##### <a name="-wildfly--restart--port"></a>`port`

Data type: `String`

The port of the JBoss Management service.

Default value: `$wildfly::properties['jboss.management.http.port']`

##### <a name="-wildfly--restart--secure"></a>`secure`

Data type: `Boolean`

Use https port or http port.

Default value: `$wildfly::secure_mgmt_api`

### <a name="wildfly--security--domain"></a>`wildfly::security::domain`

This is a defined resource type for creating a security domain
Please also see: https://docs.jboss.org/author/display/WFLY9/Security+subsystem+configuration

[*domain_name*]
 Name of the security domain to be created on the Wildfly server.

[*login_modules*]
 A hash with a specification of all login-modules to add to the domain.
 Also see the documentation of `wildfly::security::login_module`
 Example:
   { 'login-module-1' => {
       domain_name => 'my-security-domain',
       code => 'DirectDomain',
       flag => 'required',
       module_options => { realm => 'my-security-realm' }
     },
     'login-module-2' => {
       ...
     }
   }

#### Parameters

The following parameters are available in the `wildfly::security::domain` defined type:

* [`domain_name`](#-wildfly--security--domain--domain_name)
* [`login_modules`](#-wildfly--security--domain--login_modules)

##### <a name="-wildfly--security--domain--domain_name"></a>`domain_name`

Data type: `String`



Default value: `$title`

##### <a name="-wildfly--security--domain--login_modules"></a>`login_modules`

Data type: `Hash`



Default value: `{}`

### <a name="wildfly--security--group_role_mapping"></a>`wildfly::security::group_role_mapping`

The wildfly::security::group_role_mapping class.

#### Parameters

The following parameters are available in the `wildfly::security::group_role_mapping` defined type:

* [`role`](#-wildfly--security--group_role_mapping--role)
* [`group`](#-wildfly--security--group_role_mapping--group)
* [`realm`](#-wildfly--security--group_role_mapping--realm)

##### <a name="-wildfly--security--group_role_mapping--role"></a>`role`

Data type: `Any`



##### <a name="-wildfly--security--group_role_mapping--group"></a>`group`

Data type: `Any`



Default value: `$title`

##### <a name="-wildfly--security--group_role_mapping--realm"></a>`realm`

Data type: `Any`



Default value: `undef`

### <a name="wildfly--security--ldap_realm"></a>`wildfly::security::ldap_realm`

This defined resource configures a (opiniated!!) LDAP security realm.

Based on (among others):
- https://access.redhat.com/documentation/en-US/JBoss_Enterprise_Application_Platform/6/html/Development_Guide/Add_a_New_Security_Realm.html
- https://docs.jboss.org/author/display/WFLY9/Security+Realms
- https://docs.jboss.org/author/display/WFLY9/The+native+management+API
- https://docs.jboss.org/author/display/WFLY9/Security+subsystem+configuration
- http://wildscribe.github.io/Wildfly/9.0.0.Final/core-service/management/security-realm/index.html

 The realm created is a security realm that can be associated with a management interface and used
 to control access to the management and/or application services.
 This LDAP security realm uses LDAP as the user repository to determine who is trying to log
 in (authentication).
 The authorization in this LDAP realm performs a group search in the LDAP server, where the group
 entry contains an attribute referencing it's members (`member` attribute). A simple filter configuration
 to identify the users distinguished name from their username is then used to create the mapping
 between user and LDAP groups.
 This configuration assumes the 'group-to-principal' and 'username-filter' to be used. Future versions
 of this type might also allow 'principal-to-group' and 'advanced-filter'/'username-is-dn'. It does
 *not* at this time. Also this module assumes the same type of cache to be used for both group and
 username searches.

 When using this security realm, you should also create group mappings in order to map
 LDAP group names to the default Wildfly roles. See: `wildfly_wrapper::ldap_group_mapping`.

[*ldap_url*]
 URL to connect to the LDAP server. E.g.: 'ldap://ldap.my.org:389'

[*ldap_search_dn*]
 DN to use to connect to LDAP. E.g. 'uid=appserver,cn=users,ou=services,o=my,c=org'

[*ldap_search_credential*]
 Password (plain text) to use to connect to LDAP. This is the password for the
 user specified in ldap_search_dn.

[*ldap_user_base_dn*]
 The context from where to start searching users. E.g. 'cn=users,ou=services,o=my,c=org'

[*authorization_group_base_dn*]
 The context from where to start searching for groups. E.g. 'cn=groups,ou=services,o=my,c=org'

[*realm_name*]
 The name of this LDAP Security Realm. Default: $title of this resource

[*authentication_user_dn*]
 The name of the attribute which is the user's distinguished name. Default: `dn`

[*authentication_username_attribute*]
 The name of the attribute to search for the user. This filter will then perform
 a simple search where the username entered by the user matches the attribute specified here.

[*authentication_username_load*]
 The name of the attribute that should be loaded from the authenticated users LDAP entry to
 replace the username that they supplied, e.g. convert an e-mail address to an ID or correct
 the case entered. Default: `undef`

[*authentication_recursive*]
 Whether the search should be recursive. Default: `false`

[*authentication_allow_empty_passwords*]
 Should empty passwords be accepted from the user being authenticated. Default: `false`

[*authorization_group_name*]
 An enumeration to identify if groups should be referenced using a simple name or
 their distinguished name. Defalt value: `SIMPLE`

[*authorization_group_name_attribute*]
 Which attribute on a group entry is it's simple name. Default: `cn`
 When setting to `undef` the Wildfly default is used, which is: `uid`

[*authorization_group_dn_attribute*]
 Which attribute on a group entry is it's distinguished name. Default: `dn`

[*authorization_group_search_by*]
 Should searches be performed using simple names or distinguished names?
 Default: `DISTINGUISHED_NAME`

[*authorization_principal_attribute*]
 The attribute on the group entry that references the principal.
 Default value: `member`

[*authorization_group_recursive*]
 Should levels below the starting point be recursively searched?
 Default: `true`. When setting to `undef` the Wildfly default will
 be used which is: `false`

[*authorization_group_iterative*]
 Should further searches be performed to identify groups that the groups identified
 are a member of (groups of groups)? Default: `false`

[*authorization_prefer_original_conn*]
 After following a referral should subsequent searches prefer the original connection
 or use the connection of the last referral. Default: `true`

[*authorization_user_name_attribute*]
 The attribute on the user entry that is their username. Default: `uid`

[*authorization_user_dn_attribute*]
 The attribute on the user entry that contains their distinguished name.
 Default value: `dn`

[*authorization_user_force*]
 Authentication may have already converted the username to a distinguished name,
 force this to occur again before loading groups. Default: `false`

[*authorization_user_recursive*]
 Should levels below the starting point be recursively searched (e.g. sub ou's)?
 Default: `false`

[*apply_to_management_interface*]
 Apply the created security realm to the Wildfly management interface?
 Default: `false`

[*cache_type*]
 Defines which type of cache to use for previous username-filter results.
 Valid values: `by-search-time` or `by-access-time`. Default: `by-access-time`.

[*max_cache_size*]
 The maximum size of the cache before the oldest items are removed to make room
 for new entries. Default: `1000`
 When setting to `undef` the Wildfly default will be used which is `0` (unlimited)

[*cache_eviction_time*]
 The time in seconds until an entry should be evicted from the cache. Default: `900`

[*cache_failures*]
 Should failures be cached? Default: `false`

#### Parameters

The following parameters are available in the `wildfly::security::ldap_realm` defined type:

* [`ldap_url`](#-wildfly--security--ldap_realm--ldap_url)
* [`ldap_search_dn`](#-wildfly--security--ldap_realm--ldap_search_dn)
* [`ldap_search_credential`](#-wildfly--security--ldap_realm--ldap_search_credential)
* [`ldap_user_base_dn`](#-wildfly--security--ldap_realm--ldap_user_base_dn)
* [`authorization_group_base_dn`](#-wildfly--security--ldap_realm--authorization_group_base_dn)
* [`realm_name`](#-wildfly--security--ldap_realm--realm_name)
* [`authentication_username_attribute`](#-wildfly--security--ldap_realm--authentication_username_attribute)
* [`authentication_recursive`](#-wildfly--security--ldap_realm--authentication_recursive)
* [`authentication_allow_empty_passwords`](#-wildfly--security--ldap_realm--authentication_allow_empty_passwords)
* [`authorization_group_name`](#-wildfly--security--ldap_realm--authorization_group_name)
* [`authorization_group_name_attribute`](#-wildfly--security--ldap_realm--authorization_group_name_attribute)
* [`authorization_group_dn_attribute`](#-wildfly--security--ldap_realm--authorization_group_dn_attribute)
* [`authorization_group_search_by`](#-wildfly--security--ldap_realm--authorization_group_search_by)
* [`authorization_principal_attribute`](#-wildfly--security--ldap_realm--authorization_principal_attribute)
* [`authorization_group_recursive`](#-wildfly--security--ldap_realm--authorization_group_recursive)
* [`authorization_group_iterative`](#-wildfly--security--ldap_realm--authorization_group_iterative)
* [`authorization_prefer_original_conn`](#-wildfly--security--ldap_realm--authorization_prefer_original_conn)
* [`authorization_user_name_attribute`](#-wildfly--security--ldap_realm--authorization_user_name_attribute)
* [`authorization_user_dn_attribute`](#-wildfly--security--ldap_realm--authorization_user_dn_attribute)
* [`authorization_user_force`](#-wildfly--security--ldap_realm--authorization_user_force)
* [`authorization_user_recursive`](#-wildfly--security--ldap_realm--authorization_user_recursive)
* [`apply_to_management_interface`](#-wildfly--security--ldap_realm--apply_to_management_interface)
* [`cache_type`](#-wildfly--security--ldap_realm--cache_type)
* [`max_cache_size`](#-wildfly--security--ldap_realm--max_cache_size)
* [`cache_eviction_time`](#-wildfly--security--ldap_realm--cache_eviction_time)
* [`cache_failures`](#-wildfly--security--ldap_realm--cache_failures)
* [`authentication_user_dn`](#-wildfly--security--ldap_realm--authentication_user_dn)
* [`authentication_username_load`](#-wildfly--security--ldap_realm--authentication_username_load)

##### <a name="-wildfly--security--ldap_realm--ldap_url"></a>`ldap_url`

Data type: `String`



##### <a name="-wildfly--security--ldap_realm--ldap_search_dn"></a>`ldap_search_dn`

Data type: `String`



##### <a name="-wildfly--security--ldap_realm--ldap_search_credential"></a>`ldap_search_credential`

Data type: `String`



##### <a name="-wildfly--security--ldap_realm--ldap_user_base_dn"></a>`ldap_user_base_dn`

Data type: `String`



##### <a name="-wildfly--security--ldap_realm--authorization_group_base_dn"></a>`authorization_group_base_dn`

Data type: `String`



##### <a name="-wildfly--security--ldap_realm--realm_name"></a>`realm_name`

Data type: `String`



Default value: `$title`

##### <a name="-wildfly--security--ldap_realm--authentication_username_attribute"></a>`authentication_username_attribute`

Data type: `String`



Default value: `'uid'`

##### <a name="-wildfly--security--ldap_realm--authentication_recursive"></a>`authentication_recursive`

Data type: `Boolean`



Default value: `true`

##### <a name="-wildfly--security--ldap_realm--authentication_allow_empty_passwords"></a>`authentication_allow_empty_passwords`

Data type: `Boolean`



Default value: `false`

##### <a name="-wildfly--security--ldap_realm--authorization_group_name"></a>`authorization_group_name`

Data type: `String`



Default value: `'SIMPLE'`

##### <a name="-wildfly--security--ldap_realm--authorization_group_name_attribute"></a>`authorization_group_name_attribute`

Data type: `String`



Default value: `'cn'`

##### <a name="-wildfly--security--ldap_realm--authorization_group_dn_attribute"></a>`authorization_group_dn_attribute`

Data type: `String`



Default value: `'dn'`

##### <a name="-wildfly--security--ldap_realm--authorization_group_search_by"></a>`authorization_group_search_by`

Data type: `String`



Default value: `'DISTINGUISHED_NAME'`

##### <a name="-wildfly--security--ldap_realm--authorization_principal_attribute"></a>`authorization_principal_attribute`

Data type: `String`



Default value: `'member'`

##### <a name="-wildfly--security--ldap_realm--authorization_group_recursive"></a>`authorization_group_recursive`

Data type: `Boolean`



Default value: `true`

##### <a name="-wildfly--security--ldap_realm--authorization_group_iterative"></a>`authorization_group_iterative`

Data type: `Boolean`



Default value: `false`

##### <a name="-wildfly--security--ldap_realm--authorization_prefer_original_conn"></a>`authorization_prefer_original_conn`

Data type: `Boolean`



Default value: `true`

##### <a name="-wildfly--security--ldap_realm--authorization_user_name_attribute"></a>`authorization_user_name_attribute`

Data type: `String`



Default value: `'uid'`

##### <a name="-wildfly--security--ldap_realm--authorization_user_dn_attribute"></a>`authorization_user_dn_attribute`

Data type: `String`



Default value: `'dn'`

##### <a name="-wildfly--security--ldap_realm--authorization_user_force"></a>`authorization_user_force`

Data type: `Boolean`



Default value: `false`

##### <a name="-wildfly--security--ldap_realm--authorization_user_recursive"></a>`authorization_user_recursive`

Data type: `Boolean`



Default value: `false`

##### <a name="-wildfly--security--ldap_realm--apply_to_management_interface"></a>`apply_to_management_interface`

Data type: `Boolean`



Default value: `false`

##### <a name="-wildfly--security--ldap_realm--cache_type"></a>`cache_type`

Data type: `Enum['by-search-time', 'by-access-time']`



Default value: `'by-access-time'`

##### <a name="-wildfly--security--ldap_realm--max_cache_size"></a>`max_cache_size`

Data type: `Integer[0]`



Default value: `1000`

##### <a name="-wildfly--security--ldap_realm--cache_eviction_time"></a>`cache_eviction_time`

Data type: `Integer[0]`



Default value: `900`

##### <a name="-wildfly--security--ldap_realm--cache_failures"></a>`cache_failures`

Data type: `Boolean`



Default value: `false`

##### <a name="-wildfly--security--ldap_realm--authentication_user_dn"></a>`authentication_user_dn`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-wildfly--security--ldap_realm--authentication_username_load"></a>`authentication_username_load`

Data type: `Optional[String]`



Default value: `undef`

### <a name="wildfly--security--login_module"></a>`wildfly::security::login_module`

This is the login-module configuration for a security domain
Multiple login-modules can be specified for a single security domain.

[*domain_name*]
 Name of the security domain to be created on the Wildfly server.

[*code*]
 Login module code to use. See: https://docs.jboss.org/author/display/WFLY9/Authentication+Modules

[*flag*]
 The flag controls how the module participates in the overall procedure. Allowed values are:
 `requisite`, `required`, `sufficient` or `optional`. Default: `required`.

[*module_options*]
 A hash of module options containing name/value pairs. E.g.:
 `{ 'name1' => 'value1', 'name2' => 'value2' }`
 or in Hiera:
 ```
  module_options:
   name1: value1
   name2: value2
 ```

#### Parameters

The following parameters are available in the `wildfly::security::login_module` defined type:

* [`code`](#-wildfly--security--login_module--code)
* [`domain_name`](#-wildfly--security--login_module--domain_name)
* [`flag`](#-wildfly--security--login_module--flag)
* [`module_options`](#-wildfly--security--login_module--module_options)

##### <a name="-wildfly--security--login_module--code"></a>`code`

Data type: `String`



##### <a name="-wildfly--security--login_module--domain_name"></a>`domain_name`

Data type: `String`



Default value: `$title`

##### <a name="-wildfly--security--login_module--flag"></a>`flag`

Data type: `Enum['requisite', 'required', 'sufficient', 'optional']`



Default value: `'required'`

##### <a name="-wildfly--security--login_module--module_options"></a>`module_options`

Data type: `Hash`



Default value: `{}`

### <a name="wildfly--security--user_role_mapping"></a>`wildfly::security::user_role_mapping`

The wildfly::security::user_role_mapping class.

#### Parameters

The following parameters are available in the `wildfly::security::user_role_mapping` defined type:

* [`role`](#-wildfly--security--user_role_mapping--role)
* [`username`](#-wildfly--security--user_role_mapping--username)
* [`realm`](#-wildfly--security--user_role_mapping--realm)

##### <a name="-wildfly--security--user_role_mapping--role"></a>`role`

Data type: `Any`



##### <a name="-wildfly--security--user_role_mapping--username"></a>`username`

Data type: `Any`



Default value: `$title`

##### <a name="-wildfly--security--user_role_mapping--realm"></a>`realm`

Data type: `Any`



Default value: `undef`

### <a name="wildfly--system--property"></a>`wildfly::system::property`

Configures a system property

#### Parameters

The following parameters are available in the `wildfly::system::property` defined type:

* [`value`](#-wildfly--system--property--value)
* [`target_profile`](#-wildfly--system--property--target_profile)

##### <a name="-wildfly--system--property--value"></a>`value`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--system--property--target_profile"></a>`target_profile`

Data type: `Any`



Default value: `undef`

### <a name="wildfly--undertow--https"></a>`wildfly::undertow::https`

Configures a connector

#### Parameters

The following parameters are available in the `wildfly::undertow::https` defined type:

* [`socket_binding`](#-wildfly--undertow--https--socket_binding)
* [`keystore_path`](#-wildfly--undertow--https--keystore_path)
* [`keystore_relative_to`](#-wildfly--undertow--https--keystore_relative_to)
* [`keystore_password`](#-wildfly--undertow--https--keystore_password)
* [`key_alias`](#-wildfly--undertow--https--key_alias)
* [`key_password`](#-wildfly--undertow--https--key_password)
* [`target_profile`](#-wildfly--undertow--https--target_profile)
* [`enabled_protocols`](#-wildfly--undertow--https--enabled_protocols)
* [`enabled_cipher_suites`](#-wildfly--undertow--https--enabled_cipher_suites)

##### <a name="-wildfly--undertow--https--socket_binding"></a>`socket_binding`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--undertow--https--keystore_path"></a>`keystore_path`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--undertow--https--keystore_relative_to"></a>`keystore_relative_to`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--undertow--https--keystore_password"></a>`keystore_password`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--undertow--https--key_alias"></a>`key_alias`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--undertow--https--key_password"></a>`key_password`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--undertow--https--target_profile"></a>`target_profile`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--undertow--https--enabled_protocols"></a>`enabled_protocols`

Data type: `Any`



Default value: `undef`

##### <a name="-wildfly--undertow--https--enabled_cipher_suites"></a>`enabled_cipher_suites`

Data type: `Any`



Default value: `undef`

### <a name="wildfly--web--connector"></a>`wildfly::web::connector`

The wildfly::web::connector class.

#### Parameters

The following parameters are available in the `wildfly::web::connector` defined type:

* [`scheme`](#-wildfly--web--connector--scheme)
* [`protocol`](#-wildfly--web--connector--protocol)
* [`socket_binding`](#-wildfly--web--connector--socket_binding)
* [`enable_lookups`](#-wildfly--web--connector--enable_lookups)
* [`secure`](#-wildfly--web--connector--secure)

##### <a name="-wildfly--web--connector--scheme"></a>`scheme`

Data type: `Any`



##### <a name="-wildfly--web--connector--protocol"></a>`protocol`

Data type: `Any`



##### <a name="-wildfly--web--connector--socket_binding"></a>`socket_binding`

Data type: `Any`



##### <a name="-wildfly--web--connector--enable_lookups"></a>`enable_lookups`

Data type: `Any`



##### <a name="-wildfly--web--connector--secure"></a>`secure`

Data type: `Any`



### <a name="wildfly--web--ssl"></a>`wildfly::web::ssl`

The wildfly::web::ssl class.

#### Parameters

The following parameters are available in the `wildfly::web::ssl` defined type:

* [`connector`](#-wildfly--web--ssl--connector)
* [`password`](#-wildfly--web--ssl--password)
* [`protocol`](#-wildfly--web--ssl--protocol)
* [`cipher_suite`](#-wildfly--web--ssl--cipher_suite)
* [`key_alias`](#-wildfly--web--ssl--key_alias)
* [`certificate_key_file`](#-wildfly--web--ssl--certificate_key_file)
* [`ca_certificate_file`](#-wildfly--web--ssl--ca_certificate_file)

##### <a name="-wildfly--web--ssl--connector"></a>`connector`

Data type: `Any`



##### <a name="-wildfly--web--ssl--password"></a>`password`

Data type: `Any`



##### <a name="-wildfly--web--ssl--protocol"></a>`protocol`

Data type: `Any`



##### <a name="-wildfly--web--ssl--cipher_suite"></a>`cipher_suite`

Data type: `Any`



##### <a name="-wildfly--web--ssl--key_alias"></a>`key_alias`

Data type: `Any`



##### <a name="-wildfly--web--ssl--certificate_key_file"></a>`certificate_key_file`

Data type: `Any`



##### <a name="-wildfly--web--ssl--ca_certificate_file"></a>`ca_certificate_file`

Data type: `Any`



Default value: `undef`

## Resource types

### <a name="wildfly_cli"></a>`wildfly_cli`

Executes JBoss-CLI commmands

#### Properties

The following properties are available in the `wildfly_cli` type.

##### `executed`

Whether the command should be executed or not

Default value: `true`

#### Parameters

The following parameters are available in the `wildfly_cli` type.

* [`command`](#-wildfly_cli--command)
* [`host`](#-wildfly_cli--host)
* [`onlyif`](#-wildfly_cli--onlyif)
* [`password`](#-wildfly_cli--password)
* [`port`](#-wildfly_cli--port)
* [`provider`](#-wildfly_cli--provider)
* [`refreshonly`](#-wildfly_cli--refreshonly)
* [`secure`](#-wildfly_cli--secure)
* [`skip_absent`](#-wildfly_cli--skip_absent)
* [`unless`](#-wildfly_cli--unless)
* [`username`](#-wildfly_cli--username)

##### <a name="-wildfly_cli--command"></a>`command`

The actual commmand to execute

##### <a name="-wildfly_cli--host"></a>`host`

Host of Management API. Defaults to 127.0.0.1

Default value: `127.0.0.1`

##### <a name="-wildfly_cli--onlyif"></a>`onlyif`

If this parameter is set, then CLI command will only run if this command returns false

##### <a name="-wildfly_cli--password"></a>`password`

JBoss Management User Password

##### <a name="-wildfly_cli--port"></a>`port`

Management port. Defaults to 9990

Default value: `9990`

##### <a name="-wildfly_cli--provider"></a>`provider`

The specific backend to use for this `wildfly_cli` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-wildfly_cli--refreshonly"></a>`refreshonly`

Valid values: `true`, `false`, `yes`, `no`

If this parameter is set, then CLI command will only run if the resource was notified

Default value: `false`

##### <a name="-wildfly_cli--secure"></a>`secure`

Use TLS to connect with the management API

Default value: `false`

##### <a name="-wildfly_cli--skip_absent"></a>`skip_absent`

Valid values: `true`, `false`, `yes`, `no`

If this parameter is set, then CLI command will only run if resource is present

Default value: `false`

##### <a name="-wildfly_cli--unless"></a>`unless`

If this parameter is set, then CLI command will only run if this command returns true

##### <a name="-wildfly_cli--username"></a>`username`

JBoss Management User

### <a name="wildfly_deployment"></a>`wildfly_deployment`

Manages JBoss deployment

#### Properties

The following properties are available in the `wildfly_deployment` type.

##### `content`

SHA1 of deployed content

Default value: `''`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `wildfly_deployment` type.

* [`host`](#-wildfly_deployment--host)
* [`name`](#-wildfly_deployment--name)
* [`operation_headers`](#-wildfly_deployment--operation_headers)
* [`password`](#-wildfly_deployment--password)
* [`port`](#-wildfly_deployment--port)
* [`provider`](#-wildfly_deployment--provider)
* [`secure`](#-wildfly_deployment--secure)
* [`server_group`](#-wildfly_deployment--server_group)
* [`source`](#-wildfly_deployment--source)
* [`timeout`](#-wildfly_deployment--timeout)
* [`username`](#-wildfly_deployment--username)

##### <a name="-wildfly_deployment--host"></a>`host`

Host of Management API. Defaults to 127.0.0.1

Default value: `127.0.0.1`

##### <a name="-wildfly_deployment--name"></a>`name`

namevar

Deployable name

##### <a name="-wildfly_deployment--operation_headers"></a>`operation_headers`

Operation headers.

##### <a name="-wildfly_deployment--password"></a>`password`

JBoss Management User Password

##### <a name="-wildfly_deployment--port"></a>`port`

Management port. Defaults to 9990

Default value: `9990`

##### <a name="-wildfly_deployment--provider"></a>`provider`

The specific backend to use for this `wildfly_deployment` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-wildfly_deployment--secure"></a>`secure`

Use TLS to connect with the management API

Default value: `false`

##### <a name="-wildfly_deployment--server_group"></a>`server_group`

Deployment target server-group. Domain mode only.

##### <a name="-wildfly_deployment--source"></a>`source`

Deployment source file. (e.g. /tmp/file.war)

##### <a name="-wildfly_deployment--timeout"></a>`timeout`

Operation timeout. Defaults to 120

Default value: `300`

##### <a name="-wildfly_deployment--username"></a>`username`

JBoss Management User

### <a name="wildfly_resource"></a>`wildfly_resource`

Manages JBoss resources like datasources, messaging, ssl, modcluster, etc

#### Properties

The following properties are available in the `wildfly_resource` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `state`

Resource state

#### Parameters

The following parameters are available in the `wildfly_resource` type.

* [`host`](#-wildfly_resource--host)
* [`operation_headers`](#-wildfly_resource--operation_headers)
* [`password`](#-wildfly_resource--password)
* [`path`](#-wildfly_resource--path)
* [`port`](#-wildfly_resource--port)
* [`provider`](#-wildfly_resource--provider)
* [`recursive`](#-wildfly_resource--recursive)
* [`secure`](#-wildfly_resource--secure)
* [`username`](#-wildfly_resource--username)

##### <a name="-wildfly_resource--host"></a>`host`

namevar

Host of Management API. Defaults to 127.0.0.1

Default value: `127.0.0.1`

##### <a name="-wildfly_resource--operation_headers"></a>`operation_headers`

Operation headers.

##### <a name="-wildfly_resource--password"></a>`password`

JBoss Management User Password

##### <a name="-wildfly_resource--path"></a>`path`

namevar

JBoss Resource Path

##### <a name="-wildfly_resource--port"></a>`port`

namevar

Management port. Defaults to 9990

Default value: `9990`

##### <a name="-wildfly_resource--provider"></a>`provider`

The specific backend to use for this `wildfly_resource` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-wildfly_resource--recursive"></a>`recursive`

Recursively manage resource. Defaults to false

Default value: `false`

##### <a name="-wildfly_resource--secure"></a>`secure`

Use TLS to connect with the management API

Default value: `false`

##### <a name="-wildfly_resource--username"></a>`username`

JBoss Management User

### <a name="wildfly_restart"></a>`wildfly_restart`

Manage JBoss restarts.

#### Properties

The following properties are available in the `wildfly_restart` type.

##### `pending`

Whether the restart should be executed or not

Default value: `true`

#### Parameters

The following parameters are available in the `wildfly_restart` type.

* [`host`](#-wildfly_restart--host)
* [`name`](#-wildfly_restart--name)
* [`password`](#-wildfly_restart--password)
* [`port`](#-wildfly_restart--port)
* [`provider`](#-wildfly_restart--provider)
* [`reload`](#-wildfly_restart--reload)
* [`retries`](#-wildfly_restart--retries)
* [`secure`](#-wildfly_restart--secure)
* [`username`](#-wildfly_restart--username)
* [`wait`](#-wildfly_restart--wait)

##### <a name="-wildfly_restart--host"></a>`host`

Host of Management API. Defaults to 127.0.0.1

Default value: `127.0.0.1`

##### <a name="-wildfly_restart--name"></a>`name`

namevar

Informational name

##### <a name="-wildfly_restart--password"></a>`password`

JBoss Management User Password

##### <a name="-wildfly_restart--port"></a>`port`

Management port. Defaults to 9990

Default value: `9990`

##### <a name="-wildfly_restart--provider"></a>`provider`

The specific backend to use for this `wildfly_restart` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-wildfly_restart--reload"></a>`reload`

Whether the server should only reload instead of restarting.

Default value: `false`

##### <a name="-wildfly_restart--retries"></a>`retries`

Number of times it will check if server is running after a restart

Default value: `3`

##### <a name="-wildfly_restart--secure"></a>`secure`

Use TLS  to connect with the management API

Default value: `false`

##### <a name="-wildfly_restart--username"></a>`username`

JBoss Management User

##### <a name="-wildfly_restart--wait"></a>`wait`

Amount of time (in seconds) that it will wait before next attempt

Default value: `10`

## Functions

### <a name="os_config"></a>`os_config`

Type: Puppet Language

Default OS configuration for a specific distribution and version.

#### `os_config(String $distribution, String $version)`

Default OS configuration for a specific distribution and version.

Returns: `Hash[String, String]` OS configuration: user, group, dirname and console_log.

##### `distribution`

Data type: `String`

Wildfly distribution: 'wildfly' or 'jboss-eap'.

##### `version`

Data type: `String`

Wildfly version.

### <a name="wildfly--objectify"></a>`wildfly::objectify`

Type: Ruby 4.x API

Converts a LIST of STRINGs and OBJECTs into an OBJECT of OBJECTs.

#### `wildfly::objectify(Array[Variant[String, Hash[String, Any]]] $input_list)`

Converts a LIST of STRINGs and OBJECTs into an OBJECT of OBJECTs.

Returns: `Hash`

##### `input_list`

Data type: `Array[Variant[String, Hash[String, Any]]]`



### <a name="wildfly--patch_args"></a>`wildfly::patch_args`

Type: Puppet Language

Generate args for JBoss-CLI `patch` command.

#### `wildfly::patch_args(Stdlib::Unixpath $source, Boolean $override_all, Array $override, Array $preserve)`

Generate args for JBoss-CLI `patch` command.

Returns: `String` args for patch command.

##### `source`

Data type: `Stdlib::Unixpath`

path to patch file.

##### `override_all`

Data type: `Boolean`

Whether it should solve all conflicts by overriding current files.

##### `override`

Data type: `Array`

List of files to be overridden.

##### `preserve`

Data type: `Array`

List of files to be preserved.

### <a name="wildfly--profile_path"></a>`wildfly::profile_path`

Type: Puppet Language

Transform a profile name to a JBoss-CLI profile path.

#### `wildfly::profile_path(Optional[String] $profile)`

Transform a profile name to a JBoss-CLI profile path.

Returns: `String` a profile path or an empty path.

##### `profile`

Data type: `Optional[String]`

name of the profile (e.g. full, full-ha, ha)

### <a name="wildfly--service_config"></a>`wildfly::service_config`

Type: Puppet Language

Default service configuration for a specific distribution, version
  execution mode and initsystem.

#### `wildfly::service_config(String $distribution, String $version, String $mode, Enum['sysvinit', 'systemd', 'upstart'] $init_system)`

Default service configuration for a specific distribution, version
  execution mode and initsystem.

Returns: `Hash[String, String]` service configuration: name, configuration file and template and bundled init scripts.

##### `distribution`

Data type: `String`

Wildfly distribution: 'wildfly' or 'jboss-eap'.

##### `version`

Data type: `String`

Wildfly version.

##### `mode`

Data type: `String`

Wildfly execution mode will run, 'standalone' or 'domain'.

##### `init_system`

Data type: `Enum['sysvinit', 'systemd', 'upstart']`

System's initsystem.

## Data types

### <a name="Wildfly--Config_file"></a>`Wildfly::Config_file`

The Wildfly::Config_file data type.

Alias of `Pattern[/^\w*(-?\w*)*\.xml$/]`

### <a name="Wildfly--Distribution"></a>`Wildfly::Distribution`

The Wildfly::Distribution data type.

Alias of `Enum['wildfly', 'jboss-eap']`

### <a name="Wildfly--Mode"></a>`Wildfly::Mode`

The Wildfly::Mode data type.

Alias of `Enum['standalone', 'domain']`

